pub struct AltinLock<'a> { /* private fields */ }Expand description
Corresponding to std::io::StdinLock
Implementations
Sourceimpl<'a> AltinLock<'a>
impl<'a> AltinLock<'a>
Sourcepub fn read_line(&mut self, buf: &mut String) -> Result<usize>
pub fn read_line(&mut self, buf: &mut String) -> Result<usize>
Reads a line of input, appending it to the specified buffer.
Sourcepub fn read_to_string(&mut self, buf: &mut String) -> Result<usize>
pub fn read_to_string(&mut self, buf: &mut String) -> Result<usize>
Reads all contents in this source, appending them to buf.
Sourcepub fn is_terminal(&self) -> bool
pub fn is_terminal(&self) -> bool
Returns false to indicate it isn’t a terminal/tty.